*****************************************************************************
*Project:  APSA 2004--Performance Budgeting
*Start Date:  July 20, 2004
*Authors: John Gilmour & David Lewis
*Data: apsa2005.dta
*Summary: This batch file will try and read in the data and replicate the
*analysis from our PAR article with the FY2005 PART and budget data.  After 
*this is complete we will move on to analyzing the impact of budget cuts on 
*future PART scores.
*****************************************************************************
*First, I need to do some housekeeping.
set memory 64000
set l 72
set level 95
set matsize 150

*Now I will get the data.  I will also add data on managers.
use apsa2005.dta
sort programid
joinby programid using apsa2005fix2.dta

**VARIABLE CREATION AND DATA CLEANING
**NOTE:  Note that budget1 is the change from 04-05 and budget2 is change from 
**03-04.  I accidentally switched them from before.

*The following commands create a dummy variable "demdept" that is coded 1 
*for departments associated with the Democratic party, and departments that 
*the Republican party has sought to eliminate: HUD, HHS, Education, 
*Commerce, EPA, Energy, Labor.  All other departments are coded zero. 
*generate demdept=0
*replace demdept=1 if departmentid==2
*replace demdept=1 if departmentid==5
*replace demdept=1 if departmentid==6
*replace demdept=1 if departmentid==7
*replace demdept=1 if departmentid==8
*replace demdept=1 if departmentid==10
*replace demdept=1 if departmentid==13

*These commands crate a variable called "control." It is coded 1 for 
*unified Democratic control, -1 for unified Republican control, and 0 
*for divided control.  
generate control=0 
replace control=1 if dempres==1 & demsen==1 & demhouse==1
replace control=-1 if dempres==0 & demsen==0 & demhouse==0

**Now to change the PART scores to be between 0 and 100 rather than 0 to 1
replace purpose2005=purpose2005*100
replace planning2005=planning2005*100
replace management2005=management2005*100
replace results2005=results2005*100

*Now I will generate a variable for unified democratic congress and unified control.
generate demcong=demhouse*demsen
generate unified=0
replace unified=1 if divided==0
generate unidem=demcong*unified

*Now to create duration
generate duration=2004-year

*Now take advantage of new program type data
tab pt2, generate(secprog)
tab pt3, generate(thirdprog)

replace prog1=1 if secprog1==1
replace prog3=1 if secprog2==1|thirdprog1==1
replace prog4=1 if secprog3==1|thirdprog2==1
replace prog5=1 if secprog4==1
replace prog8=1 if secprog5==1

summarize prog*
more

*I'm going to clean up the department variable a bit so that the Corps of Engineers is in DOD.  So after this change 3,14 should be missing.

generate departmentid3=departmentid
replace departmentid3=4 if departmentid==3
replace departmentid3=departmentid-1 if departmentid3>3&departmentid3<14
replace departmentid3=departmentid-2 if departmentid3>=14
more
tab departmentid3, generate (dept)

*Now a log of the actual 2003 budget as an estimate of its size
generate lnbud=ln(actualfy2003)

*These commands create a variable sizecategory in which 1 
*is for small programs (under $75 million), 2 is medium (75-500 million), 
*and 3 is large (over 500 million). 
generate sizecategory=0 
replace sizecategory=1 if estimatefy2004<=75 
replace sizecategory=2 if estimatefy2004>75 & estimatefy2004<=500 
replace sizecategory=3 if estimatefy2004>500 
generate small=0 
generate medium=0 
generate large=0 
replace small=1 if estimatefy2004<=75 
replace medium=1 if estimatefy2004>75 & estimatefy2004<=500 
replace large=1 if estimatefy2004>500 

**Now create a measure for the adequacy of performance measures.

generate pmeas=0
replace pmeas=1 if totalrating==1
tab totalrating

**Now a measure to control for entitlements and guaranteed programs
generate entitle=0
replace entitle=1 if programid==1004|programid==1007|programid==1011|programid==1018|programid==1019|programid==1068|programid==1097|programid==1135
list program2005 if entitle==1
more

**Now to makes sure totalweighted is on the right scale.
replace totalweighted2005=totalweighted2005*100
generate smtot=small*totalweighted2005
generate medtot=medium*totalweighted2005
generate lartot=large*totalweighted2005
generate ey2004tot=estimatefy2004*totalweighted



**BIVARIATE AND GRAPHICAL ANALYSIS
hist budget1, xtitle(Percentage Change in FY 2004 to FY 2005 Budget Request) t1("Second Cohort of Federal Programs Graded, FY 2005 Data") bin(15)
more
hist budget1 if budget1>-101&budget1<101, xtitle(Percentage Change in FY 2004 to FY 2005 Budget Request) t1("Second Cohort of Federal Programs Graded, FY 2005 Data") bin(15)
more
twoway lfit budget1 totalweighted2005 if budget1>-101&budget1<101, by(demdept, t2("Figure 4. PART Scores and the FY 2005 Budget by Democratic Departments") note("Graphs by Democratic Department") legend(off))  xtitle("Total Weighted PART Score") ytitle("Percentage Change in FY 2005 Budget") subtitle("") legend(off)||scatter budget1 totalweighted if budget1>-101&budget1<101, legend(off)
more
twoway lfitci budget1 totalweighted2005 if budget1>-101&budget1<101,  xtitle("Total Weighted PART Score") ytitle("Percentage Change in FY 2005 Budget") subtitle("")||scatter budget1 totalweighted if budget1>-101&budget1<101
more
scatter totalrating2005 totalweighted2005 if budget1>-101&budget1<101, xtitle("Total Weighted Part Score") ytitle("Program Categorical Grade") t1("Figure 1. PART Scores and Performance Grades")
more
twoway lfit budget1 totalweighted if budget1>-101&budget1<101, t1("FY 2005 Budget") xtitle("Total Weighted Part Score") ytitle("Change in Program Budget FY 2004 to FY 2005")||scatter budget1 totalweighted if budget1>-101&budget1<101, legend(off)
more
twoway lfit budget1 totalweighted2005 if budget1>-101&budget1<101, by(sizecategory, t2("Figure X. PART Scores and the FY 2005 Budget by Program Size") note("Graphs by Program Size") legend(off))  xtitle("Total Weighted PART Score") ytitle("Percentage Change in FY 2005 Budget") subtitle("") legend(off)||scatter budget1 totalweighted if budget1>-101&budget1<101, legend(off)
more
twoway lfit budget1 purpose2005 if budget1>-101&budget1<101, by(pmeas, t2("Figure X. Program Purpose Scores and the FY 2005 Budget by Adequacy of Performance Measures") note("Graphs by Adequacy of Performance Measures") legend(off))  xtitle("Program Purpose Score") ytitle("Percentage Change in FY 2005 Budget") subtitle("") legend(off)||scatter budget1 purpose2005 if budget1>-101&budget1<101, legend(off)
more

**SIMPLE REGRESSIONS
*Table 1
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101
hettest
*This test for heteroskedasticity indicates that I can reject the null of homoskedastic errors.  We therefore use robust standard errors.
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 totalweighted2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust

**Note: the coefficient estimate on tw2005 gets smaller when exclude budget changes of more than -50 or +50 percent
**The political variables also get smaller, particularly demdept and control.  Budget is significant in some specifications.
more

*Table 3.
reg budget1 purpose2005 planning2005 management2005 results2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1  results2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 management2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 planning2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 purpose2005  demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101, robust

*Table 4.  These are regressions accounting for availability of good performance measures.
reg budget1 purpose2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&pmeas==0&budget1>-101&budget1<101, robust
reg budget1 purpose2005 demdept budget2 control duration prog1-prog3 prog5 prog7 prog8 if entitle==0&pmeas==0&budget1>-101&budget1<101, robust
more
reg budget1 purpose2005 demdept budget2 prog1-prog3 prog5 prog7 prog8 if entitle==0&pmeas==1&budget1>-101&budget1<101, robust
reg budget1 purpose2005 demdept budget2 control duration prog1-prog3 prog5 prog7 prog8 if entitle==0&pmeas==1&budget1>-101&budget1<101, robust
more

**Now to create the necessary interactions
generate ppurp=purpose2005*pmeas 
generate pdem=pmeas*demdept
generate pcon=pmeas*control
generate pdur=pmeas*duration
generate pbud=pmeas*budget2
generate pprog1=pmeas*prog1
generate pprog2=pmeas*prog2
generate pprog3=pmeas*prog3
generate pprog4=pmeas*prog4
generate pprog5=pmeas*prog5
generate pprog6=pmeas*prog6
generate pprog7=pmeas*prog7
generate pprog8=pmeas*prog8

reg budget1 purpose2005 demdept budget2 control duration prog1-prog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 purpose2005 demdept budget2 control duration ppurp pdem pcon pdur pmeas prog1-prog8 pprog1-pprog8 if entitle==0&budget1>-101&budget1<101, robust
reg budget1 purpose2005 demdept budget2 control duration ppurp pmeas prog1-prog8 pprog1-pprog8 if entitle==0&budget1>-101&budget1<101, robust

**Table 5.
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&small==1, robust
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&medium==1, robust
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&large==1, robust
reg budget1 totalweighted2005 demdept budget2 prog1-prog3 prog5 prog7-prog8 small smtot medium medtot if entitle==0&budget1>-101&budget1<101, robust

reg budget1 totalweighted2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&small==1, robust
reg budget1 totalweighted2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&medium==1, robust
reg budget1 totalweighted2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 if entitle==0&budget1>-101&budget1<101&large==1, robust
reg budget1 totalweighted2005 demdept budget2 control duration prog1-prog3 prog5 prog7-prog8 small smtot medium medtot if entitle==0&budget1>-101&budget1<101, robust

